@@ -19,12 +19,13 @@
     .factory('horizon.app.core.openstack-service-api.zun', ZunAPI);
 
   ZunAPI.$inject = [
+    '$location',
     'horizon.framework.util.http.service',
     'horizon.framework.widgets.toast.service',
     'horizon.framework.util.i18n.gettext'
   ];
 
-  function ZunAPI(apiService, toastService, gettext) {
+  function ZunAPI($location, apiService, toastService, gettext) {
     var containersPath = '/api/zun/containers/';
     var zunAvailabilityZonesPath = '/api/zun/availability_zones/';
     var capsulesPath = '/api/zun/capsules/';
@@ -60,9 +61,10 @@
       pullImage: pullImage,
       getImages: getImages,
       deleteImage: deleteImage,
-      getHosts: getHosts
+      getHosts: getHosts,
+      getHost: getHost,
+      isAdmin: isAdmin
     };
-
     return service;
 
     ///////////////
@@ -81,7 +83,7 @@
 
     function getContainer(id, suppressError) {
       var promise = apiService.get(containersPath + id);
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to retrieve the Container.');
         toastService.add('error', msg);
       });
@@ -94,7 +96,7 @@
 
     function deleteContainer(id, suppressError) {
       var promise = apiService.delete(containersPath, [id]);
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to delete the Container with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: id }, true));
       });
@@ -108,7 +110,7 @@
 
     function deleteContainerForce(id, suppressError) {
       var promise = apiService.delete(containersPath + id + '/force', [id]);
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to delete forcely the Container with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: id }, true));
       });
@@ -116,7 +118,7 @@
 
     function deleteContainerStop(id, suppressError) {
       var promise = apiService.delete(containersPath + id + '/stop', [id]);
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to stop and delete the Container with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: id }, true));
       });
@@ -223,7 +225,7 @@
 
     function deleteCapsule(id, suppressError) {
       var promise = apiService.delete(capsulesPath, [id]);
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to delete the Capsule with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: id }, true));
       });
@@ -243,9 +245,12 @@
       return apiService.get(imagesPath).error(error(msg));
     }
 
-    function deleteImage(id, host) {
-      var msg = gettext('Unable to delete the Image.');
-      return apiService.delete(imagesPath + id, {host: host}).error(error(msg));
+    function deleteImage(id, suppressError) {
+      var promise = apiService.delete(imagesPath, [id]);
+      return suppressError ? promise : promise.catch(function onError() {
+        var msg = gettext('Unable to delete the Image with id: %(id)s');
+        toastService.add('error', interpolate(msg, { id: id }, true));
+      });
     }
 
     ///////////
@@ -257,10 +262,25 @@
       return apiService.get(hostsPath).error(error(msg));
     }
 
+    function getHost(id) {
+      var msg = gettext('Unable to retrieve the Host.');
+      return apiService.get(hostsPath + id).error(error(msg));
+    }
+
     function error(message) {
       return function() {
         toastService.add('error', message);
       };
     }
+
+    function isAdmin() {
+      var isAdmin = false;
+      if ($location.url().startsWith("/admin") ||
+        $location.url().endsWith("?nav=%2Fadmin%2Fcontainer%2Fcontainers%2F")
+      ) {
+        isAdmin = true;
+      }
+      return isAdmin;
+    }
   }
 }());
